@@ -220,8 +220,8 @@ def vv_collisions(T: float, T1_1: float, T1_2: float, idata: np.ndarray, molecul
         An array containing the averaged quantities listed above (in the same order)
     
     """
-    a = np.arange(0, molecule1.num_vibr + 1)
-    b = np.arange(0, molecule2.num_vibr + 1)
+    a = np.arange(0, molecule1.num_vibr_levels(T, T1_1, True) + 1)
+    b = np.arange(0, molecule2.num_vibr_levels(T, T1_2, True) + 1)
     vibr_exp = molecule1.vibr_exp(a, T, T1_1)
     vibr_exp2 = molecule2.vibr_exp(b, T, T1_2)
     return raw_vv_collisions(T, idata, molecule1.Z_vibr(T, T1_1), molecule2.Z_vibr(T, T1_2),
