@@ -14,7 +14,7 @@ from scipy.misc import factorial
 from .errors import KineticlibError
 
 
-def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='IPL', dimensional: bool=True,
+def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='ESA', dimensional: bool=True,
           nokt: bool=False) -> float:
     """Returns the :math:`\\Omega^{(l,r)}`-integral for a specified potential
 
@@ -57,63 +57,51 @@ def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='IPL', dimensi
         For the 'VSS', 'LJ', 'IPL' and 'Switch' models: if `l!=r` or `l` not in `{1,2}`,
         for the 'ESA' model: if `(l,r)` not in `{(1,1), (1,2), (1,3), (1,4), (1,5), (2,2), (2,3), (2,4), (3,3), (4,4)}`
     """
-    m = idata[0]
-    sigma = idata[1]
-    eps = idata[2]
-    phizero = idata[3]
-    beta = idata[4]
-    vssc_11 = idata[5]
-    vsso_11 = idata[6]
-    vssc_22 = idata[7]
-    vsso_22 = idata[8]
 
-    if model == 'LJ' and l == r:
+    if model == 'ESA':
         if dimensional is True:
-            return omega_dimless_LJ(T, l, eps) * rigid_sphere_omega(T, l, l, m, sigma, nokt)
+            return omega_dimensionless_esa(T, l, r, idata[13], idata[14])\
+                   * omega_rigid_sphere(T, l, r, idata[0], idata[1], nokt)
         else:
-            return omega_dimless_LJ(T, l, eps)
-    elif model == 'ESA':
+            return omega_dimensionless_esa(T, l, r, idata[13], idata[14])
+    elif model == 'Switch' and l == r:
+        if T / idata[2] > 10:
+            om_dimless = omega_dimensionless_IPL(T, l, idata[1], idata[2], idata[3], idata[4])
+        else:
+            om_dimless = omega_dimensionless_LJ(T, l, idata[2])
         if dimensional is True:
-            return omega_esa(T, l, r, idata[13], idata[14]) * rigid_sphere_omega(T, l, r, m, sigma, nokt)
-        else:
-            return omega_esa(T, l, r, idata[13], idata[14])
-    elif model == 'RS':
-        if dimensional is True:
-            return rigid_sphere_omega(T, l, r, m, sigma, nokt)
-        else:
-            return 1.0
-    elif model == 'Switch' and l == r:  # eps/kT > 10
-        if T / eps > 10:
-            om_dimless = omega_dimless_IPL(T, l, sigma, eps, phizero, beta)
-        else:
-            om_dimless = omega_dimless_LJ(T, l, eps)
-        if dimensional is True:
-            return om_dimless * rigid_sphere_omega(T, l, r, m, sigma, nokt)
+            return om_dimless * omega_rigid_sphere(T, l, r, idata[0], idata[1], nokt)
         else:
             return om_dimless
+    elif model == 'LJ' and l == r:
+        if dimensional is True:
+            return omega_dimensionless_LJ(T, l, idata[2]) * omega_rigid_sphere(T, l, l, idata[0], idata[1], nokt)
+        else:
+            return omega_dimensionless_LJ(T, l, idata[2])
     elif model == 'IPL' and l == r:
         if dimensional is True:
-            return omega_dimless_IPL(T, l, sigma, eps, phizero, beta) * rigid_sphere_omega(T, l, r, m, sigma, nokt)
+            return omega_dimensionless_IPL(T, l, idata[1], idata[2], idata[3], idata[4])\
+                   * omega_rigid_sphere(T, l, r, idata[0], idata[1], nokt)
         else:
-            return omega_dimless_IPL(T, l, sigma, eps, phizero, beta)
+            return omega_dimensionless_IPL(T, l, idata[1], idata[2], idata[3], idata[4])
     elif model == 'VSS' and l == r:
-        if l == 1:
-            if dimensional is True:
-                return omega_vss(T, l, m, vssc_11, vsso_11, nokt)
-            else:
-                return omega_vss(T, l, m, vssc_11, vsso_11, nokt) / rigid_sphere_omega(T, l, r, m, sigma, False)
-        elif l == 2:
-            if dimensional is True:
-                return omega_vss(T, l, m, vssc_22, vsso_22, nokt)
-            else:
-                return omega_vss(T, l, m, vssc_22, vsso_22, nokt) / rigid_sphere_omega(T, l, r, m, sigma, False)
+        if dimensional is True:
+            return omega_vss(T, l, idata[0], idata[5 + 2 * (l - 1)], idata[6 + 2 * (l - 1)], nokt)
+        else:
+            return omega_vss(T, l, idata[0], idata[5 + 2 * (l - 1)], idata[6 + 2 * (l - 1)], nokt)\
+                   / omega_rigid_sphere(T, l, r, idata[0], idata[1], False)
+    elif model == 'RS':
+        if dimensional is True:
+            return omega_rigid_sphere(T, l, r, idata[0], idata[1], nokt)
+        else:
+            return 1.0
     else:
         raise KineticlibError('Cannot calculate the Omega^{(' + str(l) + ',' + str(r)
                               + ')} integral using the ' + model + ' potential')
 
 
-def rigid_sphere_omega(T: float, l: int, r: int, m: float, sigma: float, nokt: bool=False) -> float:
-    """Returns the :math:`\\Omega^{(l,r)}`-integral for a rigid sphere potential for any `l > 0`  and `r > 0`
+def omega_rigid_sphere(T: float, l: int, r: int, mass: float, sigma: float, nokt: bool=False) -> float:
+    """Returns the :math:`\\Omega^{(l,r)}`-integral for a rigid sphere potential for any `l > 0` and `r > 0`
 
     Parameters
     ----------
@@ -123,7 +111,7 @@ def rigid_sphere_omega(T: float, l: int, r: int, m: float, sigma: float, nokt: b
         the l degree of the integral
     r : int
         the r degree of the integral
-    m : float
+    mass : float
         the collision-reduced mass :math:`m_{cd}`
     sigma : float
         the collision diameter :math:`\\sigma_{cd}`
@@ -136,14 +124,14 @@ def rigid_sphere_omega(T: float, l: int, r: int, m: float, sigma: float, nokt: b
         The calculated rigid sphere omega integral
     """
     if nokt is False:
-        mult = (T * constants.k / (2.0 * constants.pi * m)) ** 0.5
+        mult = (T * constants.k / (2.0 * constants.pi * mass)) ** 0.5
     else:
-        mult = (1.0 / (2.0 * constants.pi * m)) ** 0.5
+        mult = (1.0 / (2.0 * constants.pi * mass)) ** 0.5
 
     return 0.5 * mult * constants.pi * factorial(r + 1) * (1.0 - 0.5 * (1.0 + (-1) ** l) / (l + 1)) * (sigma ** 2)
 
 
-def omega_dimless_LJ(T: float, l: int, eps: float) -> float:
+def omega_dimensionless_LJ(T: float, l: int, eps: float) -> float:
     """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the Lennard Jones potential (for `l=1` and `l=2`)
 
     Parameters
@@ -168,7 +156,7 @@ def omega_dimless_LJ(T: float, l: int, eps: float) -> float:
     if l == 1:
         tmp = np.log(T / eps) + 1.4
         f = [-0.16845, -0.02258, 0.19779, 0.64373, -0.09267, 0.00711]
-    elif l == 2:  # l = 2
+    elif l == 2:
         tmp = np.log(T / eps) + 1.5
         f = [-0.40811, -0.05086, 0.3401, 0.70375, -0.10699, 0.00763]
     else:
@@ -178,7 +166,7 @@ def omega_dimless_LJ(T: float, l: int, eps: float) -> float:
                 + f[4] * (tmp ** 2) + f[5] * (tmp ** 3))
 
 
-def omega_dimless_IPL(T: float, l: int, sigma: float, eps: float, phizero: float, beta: float) -> float:
+def omega_dimensionless_IPL(T: float, l: int, sigma: float, eps: float, phizero: float, beta: float) -> float:
     """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the IPL potential (for `l=1` and `l=2`)
 
     Parameters
@@ -218,7 +206,7 @@ def omega_dimless_IPL(T: float, l: int, sigma: float, eps: float, phizero: float
         coeff = 0.89
         pows = np.array([2, 4, 6])
         TT = Tstar
-    elif l == 2:  # l == 2
+    elif l == 2:
         a = np.array([[-33.0838, 20.0862, 72.1059, 68.5001],
                       [101.571, -56.4472, -286.393, -315.4531],
                       [-87.7036, 46.313, 227.146, 363.1807]])
@@ -234,7 +222,7 @@ def omega_dimless_IPL(T: float, l: int, sigma: float, eps: float, phizero: float
            ((rstar * np.log(vstar / Tstar)) ** 2)
 
 
-def omega_vss(T: float, l: int, m: float, vssc: float, vsso: float, nokt: bool=False) -> float:
+def omega_vss(T: float, l: int, mass: float, vssc: float, vsso: float, nokt: bool=False) -> float:
     """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the VSS potential (for `l=1` and `l=2`)
 
     Parameters
@@ -243,7 +231,7 @@ def omega_vss(T: float, l: int, m: float, vssc: float, vsso: float, nokt: bool=F
         the temperature of the mixture
     l : int
         the l degree of the integral
-    m : float
+    mass : float
         the collision-reduced mass :math:`m_{cd}`
     vssc : float
         the VSS potential :math:`C` parameter
@@ -263,21 +251,21 @@ def omega_vss(T: float, l: int, m: float, vssc: float, vsso: float, nokt: bool=F
         if `l` not in `{1,2}`
     """
     if nokt is False:
-        multiplier = vssc * ((T * constants.k / (2 * constants.pi * m)) ** 0.5) * (T ** (-vsso))
+        mult = ((T * constants.k / (2 * constants.pi * mass)) ** 0.5)
     else:
-        multiplier = vssc * ((1 / (2 * constants.pi * m)) ** 0.5) * (T ** (-vsso))
+        mult = ((1 / (2 * constants.pi * mass)) ** 0.5)
     if l == 1:
-        integral = 0.5 * gamma(3 - vsso)
-        return multiplier * integral * (constants.physical_constants['Angstrom star'][0] ** 2)
+        return 0.5 * vssc * mult * gamma(3 - vsso) * (constants.physical_constants['Angstrom star'][0] ** 2)\
+                   * (T ** (-vsso))
     elif l == 2:
-        integral = 0.5 * gamma(4 - vsso)
-        return multiplier * integral * (constants.physical_constants['Angstrom star'][0] ** 2)
+        return 0.5 * vssc * mult * gamma(4 - vsso) * (constants.physical_constants['Angstrom star'][0] ** 2)\
+                   * (T ** (-vsso))
     else:
         raise KineticlibError('Cannot calculate the Omega^{(' + str(l) + ',' + str(l)
                               + ')} integral using the VSS potential')
 
 
-def omega_esa(T: float, l: int, r: int, beta: float, eps: float) -> float:
+def omega_dimensionless_esa(T: float, l: int, r: int, beta: float, eps: float) -> float:
     """Returns the dimensionless :math:`\\Omega^{(l,r)}`-integral using ESA data
 
     Parameters
