@@ -68,20 +68,53 @@ class Atom(Particle):
         The formation energy of the particle
 
     """
-    def __init__(self, name: str):
+    def __init__(self, name: str, mass=None, LJe=None, LJs=None, form=None):
         """Creates a new atom
 
         Parameters
         ----------
         name : str
             The name of the atom
+        mass : float
+            The mass of the particle (in kilograms), if one wants to use a mass different from the data included with
+            the library, if equal to None, the data included with the library is used, defaults to None
+        LJe : float
+            The particle Lennard-Jones :math:`\\varepsilon` parameter, divided by Boltzmann's constant,
+            if one wants to use a math:`\\varepsilon` parameter different from the data included with
+            the library, if equal to None, the data included with the library is used, defaults to None
+        LJs : float
+            The particle Lennard-Jones :math:`\\sigma` parameter (in meters), if one wants to use a Lennard-Jones
+            :math:`\\sigma` parameter different from the data included with
+            the library, if equal to None, the data included with the library is used, defaults to None
+        form : float
+            The formation energy of the particle (in Joules), if one wants to use a formation energy
+            different from the data included with the library, if equal to None, the data included with the library
+            is used, defaults to None
         """
-        this_dir, this_filename = split(__file__)
-        raw_d = np.genfromtxt(join(this_dir, normcase('data/particles/' + name + '.dat')))
-        mass = raw_d[0] * constants.physical_constants['atomic mass constant'][0]
-        LJe = raw_d[1]
-        LJs = raw_d[2] * constants.physical_constants['Angstrom star'][0]
-        form = 0.5 * raw_d[3] * constants.physical_constants['electron volt'][0]
+        file_opened = False
+        if mass is None:
+            if not file_opened:
+                this_dir, this_filename = split(__file__)
+                raw_d = np.genfromtxt(join(this_dir, normcase('data/particles/' + name + '.dat')))
+                file_opened = True
+            mass = raw_d[0] * constants.physical_constants['atomic mass constant'][0]
+        if LJe is None:
+            if not file_opened:
+                this_dir, this_filename = split(__file__)
+                raw_d = np.genfromtxt(join(this_dir, normcase('data/particles/' + name + '.dat')))
+                file_opened = True
+            LJe = raw_d[1]
+        if LJs is None:
+            if not file_opened:
+                this_dir, this_filename = split(__file__)
+                raw_d = np.genfromtxt(join(this_dir, normcase('data/particles/' + name + '.dat')))
+                file_opened = True
+            LJs = raw_d[2] * constants.physical_constants['Angstrom star'][0]
+        if form is None:
+            if not file_opened:
+                this_dir, this_filename = split(__file__)
+                raw_d = np.genfromtxt(join(this_dir, normcase('data/particles/' + name + '.dat')))
+            form = 0.5 * raw_d[3] * constants.physical_constants['electron volt'][0]
         Particle.__init__(self, name, mass, LJe, LJs, form)
 
 
@@ -241,26 +274,6 @@ class MoleculeSTS(Particle):
         self._current_raesq_dimensionless = self.avg_rot_energy_sq(T, False)
         self._current_T = T
 
-    def num_vibr_levels(self) -> int:
-        """Returns the amount of vibrational levels
-
-        Returns
-        -------
-        int
-            The amount of vibrational levels
-        """
-        return self.num_vibr
-
-    def vibr_one(self) -> float:
-        """Returns the energy of the first vibrational level
-
-        Returns
-        -------
-        float
-            The energy of the first vibrational level
-        """
-        return self.vibr[1]
-
     def vibr_energy(self, i):
         """Returns the energy of the `i`-th vibrational level :math:`\\varepsilon_{i}`
 
@@ -282,14 +295,13 @@ class MoleculeSTS(Particle):
 
         Parameters
         ----------
-        j : int or 1-D array-like
-            the number of the level (or a an array/list of level numbers) for which to return the rotational energy
+        j : int or float
+            the number of the level for which to return the rotational energy
 
         Returns
         -------
         float or 1-D array-like
-            The energy of the j-th rotational level, or, if the input the `j` parameter is array-like, an array of
-            rotational energies
+            The energy of the j-th rotational level, (`float` values of `j` are used for integration)
         """
         if (int(j) - j) == 0 and j <= self.num_rot:
             return self.rot[j]
@@ -326,15 +338,15 @@ class MoleculeSTS(Particle):
 
         Parameters
         ----------
-        j : int or 1-D array-like
-            the number of the level (or a an array/list of level numbers) for which to return the rotational exponent
+        j : int or float
+            the number of the level for which to return the rotational exponent
         T : float
             the temperature of the mixture
 
         Returns
         -------
         float or 1-D np.ndarray
-            The rotational exponent for a given index or set of indices `j`
+            The rotational exponent for a given index `j`
         """
         return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot_energy(j) / (constants.k * T))
 
@@ -379,7 +391,7 @@ class MoleculeSTS(Particle):
             B = self.rot_const / kT
             snr = self.num_rot * (self.num_rot + 1.0)
 
-            if dimensional == 1:
+            if dimensional is True:
                 return kT * (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
             else:
                 return (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
@@ -412,7 +424,7 @@ class MoleculeSTS(Particle):
             kT = constants.k * T
             B = self.rot_const / kT
             snr = self.num_rot * (self.num_rot + 1)
-            if dimensional == 1:
+            if dimensional is True:
                 return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) * (kT ** 2) / (self.rot_symmetry
                                                                                                 * self.Z_rot(T) * B)
             else:
@@ -454,10 +466,7 @@ class MoleculeSTS(Particle):
         if model == 'none':
             return np.sum(np.exp(-(self.vibr_zero + self.vibr) / (T * constants.k)))
         elif model == 'inf':
-            res = 0.0
-            for i in range(self.num_vibr + 1):
-                res += 1.0
-            return res
+            return self.num_vibr + 1.0
         elif model == 'D6k':
             return np.sum(np.exp(6.0 * ((self.vibr + self.vibr_zero) / self.diss)))
         elif model == '3T':
@@ -586,6 +595,8 @@ class Molecule(MoleculeSTS):
         array containing the current vibrational exponents
     _current_avg_i : float
         current value of the following quantity: :math:`\\left<i\\right>_{vibr}`
+    _current_avg_i_sq : float
+        current value of the following quantity: :math:`\\left<i^{2}\\right>_{vibr}`
     _current_wdt : float
         current derivative of average amount of vibrational quanta per unit of mass of the particular species
         with respect to the temperature T
@@ -637,6 +648,7 @@ class Molecule(MoleculeSTS):
         self._current_ni = np.zeros(self.num_vibr + 1)
         self._current_v_exp = np.zeros(self.num_vibr + 1)
         self._current_avg_i = 0.0
+        self._current_avg_i_sq = 0.0
         self._current_wdt = 0.0
         self._current_wdt1 = 0.0
         self._current_edt = 0.0
@@ -662,17 +674,7 @@ class Molecule(MoleculeSTS):
         n_c : float
             the numeric density of the molecular species
         """
-        if T < T1:
-            if self.avc == 0.0:
-                treanor_i_star = self.num_vibr
-            else:
-                treanor_i_star = int(0.5 + self.vibr[1] * T / (2 * self.avc * self.hvc * T1))
-        else:
-            treanor_i_star = int(0.5 + self.vibr[1] * T / (2 * self.avc * self.hvc * T1))
-        if self.max_vibr > treanor_i_star:
-            self.num_vibr = treanor_i_star
-        else:
-            self.num_vibr = self.max_vibr
+        self.num_vibr = self.num_vibr_levels(T, T1, True)
 
         MoleculeSTS.renorm_sts(self, T)
 
@@ -683,6 +685,7 @@ class Molecule(MoleculeSTS):
         self._current_vaesq = self.avg_vibr_energy_sq(T, T1, True)
         self._current_vaesq_dimensionless = self.avg_vibr_energy_sq(T, T1, False)
         self._current_avg_i = self.avg_i(T, T1)
+        self._current_avg_i_sq = self.avg_i_sq(T, T1)
         self._current_wdt = self.W_dT(T, T1)
         self._current_wdt1 = self.W_dT1(T, T1)
         self._current_edt = self.E_vibr_dT(T, T1)
@@ -698,11 +701,15 @@ class Molecule(MoleculeSTS):
         self._current_n = n_c
         self._current_T1 = T1
 
-    def num_vibr_levels(self, true_amt: bool=True) -> int:
+    def num_vibr_levels(self, T: float, T1: float, true_amt: bool=True) -> int:
         """Returns the amount of vibrational levels (either the maximum one or current one)
 
         Parameters
         ----------
+        T : float
+            the temperature of the mixture
+        T1 : float
+            the temperature of the first vibrational level for the molecular species
         true_amt : bool
             if True, the true amount of vibrational levels is returned (which may be smaller than the maximum one if
             T < T1), if False, the maximum amount of vibrational levels is returned, defaults to True
@@ -712,10 +719,23 @@ class Molecule(MoleculeSTS):
         bool
             The amount of vibrational levels
         """
-        if true_amt is True:
-            return self.num_vibr
-        else:
+        if true_amt is False:
             return self.max_vibr
+        else:
+            if (self._current_T != T) or (self._current_T1 != T1):
+                if T < T1:
+                    if self.avc == 0.0:
+                        treanor_i_star = self.num_vibr
+                    else:
+                        treanor_i_star = int(0.5 + self.vibr[1] * T / (2 * self.avc * self.hvc * T1))
+                else:
+                    treanor_i_star = int(0.5 + self.vibr[1] * T / (2 * self.avc * self.hvc * T1))
+                if self.max_vibr > treanor_i_star:
+                    return treanor_i_star
+                else:
+                    return self.max_vibr
+            else:
+                return self.num_vibr
 
     def vibr_exp(self, i, T: float, T1: float):
         """Returns the vibrational exponent: :math:`\\exp((-\\varepsilon_{i} - i \\varepsilon_{1}) / kT
@@ -757,7 +777,7 @@ class Molecule(MoleculeSTS):
             The vibrational partition function
         """
         if (self._current_T != T) or (self._current_T1 != T1):
-            return self.vibr_exp(np.arange(0, self.num_vibr + 1, 1), T, T1).sum()
+            return self.vibr_exp(np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1), T, T1).sum()
         else:
             return self._current_Z_vibr
 
@@ -802,7 +822,7 @@ class Molecule(MoleculeSTS):
             The averaged vibrational energy
         """
         if (self._current_T != T) or (self._current_T1 != T1):
-            a = np.arange(0, self.num_vibr + 1, 1)
+            a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
             if dimensional is True:
                 return np.dot(self.vibr_exp(a, T, T1), self.vibr[a]) / self.Z_vibr(T, T1)
             else:
@@ -856,7 +876,7 @@ class Molecule(MoleculeSTS):
             The averaged squared vibrational energy
         """
         if (self._current_T != T) or (self._current_T1 != T1):
-            a = np.arange(0, self.num_vibr + 1, 1)
+            a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
             if dim is True:
                 return np.dot(self.vibr_exp(a, T, T1), np.power(self.vibr[a], 2)) / self.Z_vibr(T, T1)
             else:
@@ -884,7 +904,7 @@ class Molecule(MoleculeSTS):
             The average amount of vibrational quanta
         """
         if (self._current_T != T) or (self._current_T1 != T1):
-            a = np.arange(0, self.num_vibr + 1, 1)
+            a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
             res = np.dot(self.vibr_exp(a, T, T1), a)
             return res / self.Z_vibr(T, T1)
         else:
@@ -906,9 +926,12 @@ class Molecule(MoleculeSTS):
         float
             The averaged squared vibrational level
         """
-        a = np.arange(0, self.num_vibr + 1, 1)
-        res = np.dot(self.vibr_exp(a, T, T1), np.power(a, 2))
-        return res / self.Z_vibr(T, T1)
+        if (self._current_T != T) or (self._current_T1 != T1):
+            a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
+            res = np.dot(self.vibr_exp(a, T, T1), np.power(a, 2))
+            return res / self.Z_vibr(T, T1)
+        else:
+            return self._current_avg_i_sq
 
     def avg_vibr_energy_i(self, T: float, T1: float, dimensional: bool=True) -> float:
         """Returns the energy level multiplied by the corresponding vibrational energy, averaged over the vibrational
@@ -932,7 +955,7 @@ class Molecule(MoleculeSTS):
             The averaged vibrational level multiplied by the corresponding vibrational energy
         """
         if (self._current_T != T) or (self._current_T1 != T1):
-            a = np.arange(0, self.num_vibr + 1, 1)
+            a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
             if dimensional is True:
                 return np.dot(a * self.vibr[a], self.vibr_exp(a, T, T1)) / self.Z_vibr(T, T1)
             else:
@@ -984,7 +1007,7 @@ class Molecule(MoleculeSTS):
             The partial derivative of the vibrational partition function with respect to the temperature :math:`T`
         """
         if (self._current_T != T) or (self._current_T1 != T1):
-            a = np.arange(0, self.num_vibr + 1, 1)
+            a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
             return np.dot(self.vibr[a] - a * self.vibr[1], self.vibr_exp(a, T, T1)) / (constants.k * T * T)
         else:
             return self._current_zdt
@@ -1007,7 +1030,7 @@ class Molecule(MoleculeSTS):
             the first vibrational level :math:`T_{1}`
         """
         if (self._current_T != T) or (self._current_T1 != T1):
-            a = np.arange(0, self.num_vibr + 1, 1)
+            a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
             return self.vibr[1] * np.dot(a, self.vibr_exp(a, T, T1)) / (constants.k * T1 * T1)
         else:
             return self._current_zdt1
@@ -1058,7 +1081,7 @@ class Molecule(MoleculeSTS):
         """
         if (self._current_T != T) or (self._current_T1 != T1):
             return self.vibr[1] * (self.avg_i_sq(T, T1) - (self.avg_i(T, T1) ** 2))\
-                   / (self.mass * constants.k * T1 * T1)
+                   / (constants.k * T1 * T1 * self.mass)
         else:
             return self._current_wdt1
 
@@ -1101,7 +1124,7 @@ class Molecule(MoleculeSTS):
             if self.vibr_model == 'harmonic':
                 return 0.0
             else:
-                return ((self.avg_vibr_energy_sq(T, T1) - (self.avg_vibr_energy(T, T1) ** 2))
+                return (self.avg_vibr_energy_sq(T, T1) - (self.avg_vibr_energy(T, T1) ** 2)
                         + self.vibr[1] * (self.avg_i(T, T1) * self.avg_vibr_energy(T, T1)
                                           - self.avg_vibr_energy_i(T, T1))) / (constants.k * T * T * self.mass)
         else:
@@ -1126,6 +1149,6 @@ class Molecule(MoleculeSTS):
         """
         if (self._current_T != T) or (self._current_T1 != T1):
             return (self.avg_vibr_energy_i(T, T1) - self.avg_i(T, T1) * self.avg_vibr_energy(T, T1))\
-                    * self.vibr[1] / (self.mass * constants.k * T1 * T1)
+                    * self.vibr[1] / (constants.k * T1 * T1 * self.mass)
         else:
             return self._current_edt1
\ No newline at end of file
