@@ -11,10 +11,10 @@ from .particles import Molecule
 
 def Y_poly_norm(T: float, T1: float, molecule: Molecule, F: float=0.0) -> float:
     """Calculates the square of the "norm" of the Waldman Trubenbacher polynomial of the following form:
-    :math:`Y_{ij} = -[\\varepsilon_{ij} / kT - i F]'`, where the :math:`i` is the vibrational level of the molecule,
+    :math:`P_{ij} = -[\\varepsilon_{ij} / kT - i F]'`, where the :math:`i` is the vibrational level of the molecule,
     :math:`j` is the rotational level of the molecule, :math:`[A]' = A - <A>_{int}`, where :math:`<>_{int}`
     denotes averaging over the internal spectrum.
-    The square of the "norm" is defined as: :math:`||Y_{ij}|| = \\left<Y_{ij}^{2} \\right>`
+    The square of the "norm" is defined as: :math:`||P_{ij}|| = \\left<P_{ij}^{2} \\right>_{int}`
 
     Parameters
     ----------
